@@ -3,6 +3,7 @@ import hildon
 from Settings import *
 import osso
 from Engine import *
+import gobject
 
 class MainOptionsDialog(gtk.Dialog):
    def __init__(self, widget):
@@ -15,7 +16,7 @@ class MainOptionsDialog(gtk.Dialog):
       pa = hildon.PannableArea()
       
       more_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-      more_button.set_text("Get More Search Engines", "Get more search engines from TouchSearch.org")
+      more_button.set_text("Add new search engines", "Download or make your own search engines")
       more_button.set_alignment(0,0,0,0)
       more_button.connect('clicked', self.show_more)
       
@@ -60,6 +61,27 @@ class MainOptionsDialog(gtk.Dialog):
       self.destroy()
       
    def show_more(self, widget):
+      dialog = gtk.Dialog("Add engines", None)
+      
+      download_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+      download_button.set_text("Get search engines", "Download search engines from TouchSearch.org")
+      download_button.set_alignment(0,0,0,0)
+      download_button.connect('clicked', self.show_download)
+      
+      create_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+      create_button.set_text("Create engine", "Make your own search engine")
+      create_button.set_alignment(0,0,0,0)
+      create_button.connect('clicked', CreateEngine)
+      
+      dialog.vbox.pack_start(download_button, True, True, 0)
+      dialog.vbox.pack_start(create_button, True, True, 0)
+      
+      dialog.show_all()
+      dialog.run()
+      dialog.destroy()
+      
+      
+   def show_download(self, widget):
       self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", ("http://www.touchsearch.org/addons/",))
    
    def show_help(self, widget):
@@ -68,13 +90,147 @@ class MainOptionsDialog(gtk.Dialog):
    def show_donate(self, widget):
       self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", ("http://www.touchsearch.org/donate/",))
       
+
+class CreateEngine(gtk.Dialog):
+   def __init__(self, widget):
+      gtk.Dialog.__init__(self, "Create engine", None)
+      ok_button = self.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
       
+      self.osso_context = osso.Context("org.touchsearch.touchsearch", "3.0", False)
+      self.osso_rpc = osso.Rpc(self.osso_context)
+      
+      main_vbox = gtk.VBox()
+      pa = hildon.PannableArea()
+      
+      help_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+      help_button.set_text("View online instructions (this will exit this dialog)", "")
+      #help_button.set_alignment(0,0,0,0)
+      help_button.connect('clicked', self.show_help)
+      
+      name_hbox = gtk.HBox()
+      name_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
+      name_hbox.pack_start(gtk.Label("Name:"), False, False, 5)
+      name_hbox.pack_start(name_entry, True, True, 5)
+      
+      category_hbox = gtk.HBox()
+      category_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
+      category_hbox.pack_start(gtk.Label("Category:"), False, False, 5)
+      category_hbox.pack_start(category_entry, True, True, 5)
+      
+      url_hbox = gtk.HBox()
+      url_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
+      url_hbox.pack_start(gtk.Label("URL:"), False, False, 5)
+      url_hbox.pack_start(url_entry, True, True, 5)
+      
+      prefix_hbox = gtk.HBox()
+      prefix_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
+      prefix_entry.set_max_length(4)
+      prefix_hbox.pack_start(gtk.Label("QuickBar Prefix:"), False, False, 5)
+      prefix_hbox.pack_start(prefix_entry, True, True, 5)
+      
+      default_icon_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+      default_icon_button.set_label("Create icon automatically")
+      default_icon_button.set_active(True)
+
+      white_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, None)
+      white_button.set_label("White")
+      white_button.set_mode(False)
+      black_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, white_button)
+      black_button.set_label("Black")
+      black_button.set_mode(False)
+      grey_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, white_button)
+      grey_button.set_label("Grey")
+      grey_button.set_mode(False)
+      
+      color_hbox = gtk.HBox()
+      color_hbox.pack_start(white_button, True, True, 0)
+      color_hbox.pack_start(black_button, True, True, 0)
+      color_hbox.pack_start(grey_button, True, True, 0)
+      
+      custom_icon_button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+      custom_icon_button.set_label("Select custom icon")
+      custom_icon_button.set_sensitive(False)
+      
+      default_icon_button.connect("toggled", self.toggled, custom_icon_button, color_hbox)
+      custom_icon_button.connect("clicked", self.open_file)
+      ok_button.connect("clicked", self.ok_callback, name_entry, category_entry, url_entry, prefix_entry, default_icon_button, custom_icon_button, white_button, black_button, grey_button)
+      
+      main_vbox.pack_start(help_button, True, True, 10)
+      main_vbox.pack_start(name_hbox, True, True, 10)
+      main_vbox.pack_start(category_hbox, True, True, 10)
+      main_vbox.pack_start(url_hbox, True, True, 10)
+      main_vbox.pack_start(prefix_hbox, True, True, 10)
+      main_vbox.pack_start(default_icon_button, True, True, 10)
+      main_vbox.pack_start(color_hbox, True, True, 10)
+      main_vbox.pack_start(custom_icon_button, True, True, 10)
+      
+      pa.add_with_viewport(main_vbox)
+      pa.set_size_request(-1, 400)
+      self.vbox.pack_start(pa, True, True, 0)
+      self.show_all()
+      self.run()
+      self.destroy()
+         
+   def ok_callback(self, widget, name_entry, category_entry, url_entry, prefix_entry, default_icon_button, custom_icon_button, white_button, black_button, grey_button):
+      
+      name = name_entry.get_text()
+      category = category_entry.get_text()
+      url = url_entry.get_text()
+      prefix = prefix_entry.get_text()
+      use_default_icon = default_icon_button.get_active()
+      custom_icon = custom_icon_button.get_value()
+      if black_button.get_active():
+         color = (0.0, 0.0, 0.0)
+      elif grey_button.get_active():
+         color = (0.7, 0.7, 0.7)
+      else:
+         color = (1.0, 1.0, 1.0)
+      
+      retcode, error = AddEngine().add(name, category, url, prefix, use_default_icon, custom_icon, color)
+      if retcode == 0: message_type = gtk.MESSAGE_INFO
+      else: message_type = gtk.MESSAGE_ERROR
+      dialog = gtk.MessageDialog(None, 0, message_type, gtk.BUTTONS_NONE, error)
+      dialog.run()
+      dialog.destroy()
+      
+      print retcode
+      print error
+      print name
+      print category
+      print url
+      print prefix
+      print use_default_icon
+      print custom_icon
+      print color
+      
+   def open_file(self, widget):
+      fc = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
+      fc.set_property('show-files', True)
+      if fc.run() == gtk.RESPONSE_OK:
+        filepath = fc.get_filename()
+        widget.set_value(filepath)
+      fc.destroy()
+      
+   def toggled(self, widget, button, hbox):
+      if widget.get_active():
+         button.set_sensitive(False)
+         hbox.set_sensitive(True)
+      else:
+         button.set_sensitive(True)
+         hbox.set_sensitive(False)
+   
+   def show_help(self, widget):
+      self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", ("http://www.touchsearch.org/help/adding-custom-search-engines/",))
+      
+
 class SettingsDialog(gtk.Dialog):
    def __init__(self, widget):
       gtk.Dialog.__init__(self, "Settings", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
       search_button = self.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
       settings = Settings()
       
+      main_vbox = gtk.VBox()
+      
       scale = hildon.GtkHScale()
       scale.set_draw_value(False)
       adjustment = scale.get_adjustment()
@@ -101,25 +257,48 @@ class SettingsDialog(gtk.Dialog):
       enhanced_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, standard_button)
       enhanced_button.set_label("Enhanced")
       enhanced_button.set_mode(False)
+
+      color_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, None)
+      color_button.set_label("Color")
+      color_button.set_mode(False)
+      ghosted_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, color_button)
+      ghosted_button.set_label("Ghosted")
+      ghosted_button.set_mode(False)
       
-      print settings.get_show_corefour()
       if settings.get_show_corefour():
          enhanced_button.set_active(True)
       else:
          standard_button.set_active(True)
+         
+      if settings.get_icon_style() == "Ghosted":
+         ghosted_button.set_active(True)
+      else:
+         color_button.set_active(True)
       
       ui_hbox = gtk.HBox()
       ui_hbox.pack_start(standard_button, True, True, 0)
       ui_hbox.pack_end(enhanced_button, True, True, 0)
       
-      self.vbox.pack_start(gtk.Label("Widget Opacity"), False, False, 0)
-      self.vbox.pack_start(scale, False, False, 10)
-      self.vbox.pack_start(gtk.HSeparator())
-      self.vbox.pack_start(gtk.Label("Favorites"), False, False, 0)
-      self.vbox.pack_start(picker, True, True, 10)
-      self.vbox.pack_start(gtk.HSeparator())
-      self.vbox.pack_start(gtk.Label("Search Dialog"), False, False, 0)
-      self.vbox.pack_start(ui_hbox, True, True, 10)
+      icon_hbox = gtk.HBox()
+      icon_hbox.pack_start(color_button, True, True, 0)
+      icon_hbox.pack_end(ghosted_button, True, True, 0)
+      
+      main_vbox.pack_start(gtk.Label("Widget Opacity"), False, False, 0)
+      main_vbox.pack_start(scale, False, False, 10)
+      main_vbox.pack_start(gtk.HSeparator())
+      main_vbox.pack_start(gtk.Label("Favorites"), False, False, 0)
+      main_vbox.pack_start(picker, True, True, 10)
+      main_vbox.pack_start(gtk.HSeparator())
+      main_vbox.pack_start(gtk.Label("Search Dialog"), False, False, 0)
+      main_vbox.pack_start(ui_hbox, True, True, 10)
+      main_vbox.pack_start(gtk.Label("Icon Style"), False, False, 0)
+      main_vbox.pack_start(icon_hbox, True, True, 10)
+      
+      pa = hildon.PannableArea()
+      pa.add_with_viewport(main_vbox)
+      pa.set_size_request(-1, 400)
+      
+      self.vbox.pack_start(pa, True, True, 0)
       self.show_all()
       response = self.run()
       
@@ -131,9 +310,14 @@ class SettingsDialog(gtk.Dialog):
             show_corefour = 0
          else:
             show_corefour = 1
+         if ghosted_button.get_active() == True:
+            icon_style = "Ghosted"
+         else:
+            icon_style = "Color"
          settings.set_show_corefour(show_corefour)
          settings.set_corefour(corefour)
          settings.set_opacity(pos)
+         settings.set_icon_style(icon_style)
          settings.write()
 
       self.destroy()
@@ -226,6 +410,7 @@ class ConfigureVbox(gtk.VBox):
       
       if model[treeiter][0] == "Google":
          delete_button.set_sensitive(False)
+         edit_button.set_sensitive(True)
       elif model[treeiter][0] == "QuickBar":
          edit_button.set_sensitive(False)
          delete_button.set_sensitive(True)
@@ -291,8 +476,11 @@ class ConfigureVbox(gtk.VBox):
       prefix_entry.set_text(engine.get_prefix())
       prefix_entry.set_max_length(4)
       
-      category_label = gtk.Label("Category: %s" % engine.get_category())
-      category_label.set_alignment(0.0, 0.0)
+      category_hbox = gtk.HBox()
+      category_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
+      category_entry.set_text(engine.get_category())
+      category_hbox.pack_start(gtk.Label("Category:"), False, False, 0)
+      category_hbox.pack_start(category_entry, True, True, 10)
       
       prefix_hbox = gtk.HBox()
       prefix_hbox.pack_start(gtk.Label("QuickBar Prefix:"), False, False, 0)
@@ -309,8 +497,8 @@ class ConfigureVbox(gtk.VBox):
       language_button.set_selector(selector)
       language_button.set_value(language)
       
-      dialog.vbox.pack_start(name_label, True, True, 5)
-      dialog.vbox.pack_start(category_label, True, True, 5)
+      dialog.vbox.pack_start(name_label, True, True, 10)
+      dialog.vbox.pack_start(category_hbox, True, True, 5)
       dialog.vbox.pack_start(prefix_hbox, True, True, 5)
       dialog.vbox.pack_start(language_button, True, True, 5)
       
@@ -319,8 +507,10 @@ class ConfigureVbox(gtk.VBox):
       
       if response == gtk.RESPONSE_OK:
          prefix = prefix_entry.get_text()
+         category = category_entry.get_text()
          language = language_button.get_value()
          engine.set_prefix(prefix)
+         engine.set_category(category)
          engine.set_language(language)
          engine.write()
          
@@ -332,7 +522,7 @@ class AboutDialog(gtk.AboutDialog):
       gtk.AboutDialog.__init__(self)
       self.set_title("About")
       self.set_name("TouchSearch")
-      self.set_version("3.0")
+      self.set_version("3.1")
       self.set_copyright("Copyright 2009, 2010 Brent Chiodo")
       self.set_authors(["Brent Chiodo <bchiodo@gmail.com>"])
       self.set_logo(gtk.gdk.pixbuf_new_from_file("/opt/touchsearch/icons/icon.png"))
