@@ -6,6 +6,6 @@ import os
 setup(name='touchsearch-dictionary',
    version='1.0',
    data_files = [
-      ('/opt/touchsearch/search_engines/Dictionary/',['Dictionary.search', 'dictionary.png'])
+      ('/opt/touchsearch/search_engines/Dictionary/',['Dictionary.search', 'dictionary_color.png', 'dictionary_ghosted.png'])
       ]
       )
\ No newline at end of file
