@@ -6,6 +6,6 @@ import os
 setup(name='touchsearch-googlemapsmobile',
    version='1.0',
    data_files = [
-      ('/opt/touchsearch/search_engines/GoogleMapsMobile/',['GoogleMapsMobile.search', 'google_maps_mobile.png'])
+      ('/opt/touchsearch/search_engines/GoogleMapsMobile/',['GoogleMapsMobile.search', 'google_maps_mobile_color.png', 'google_maps_mobile_ghosted.png'])
       ]
       )
\ No newline at end of file
