@@ -1,7 +1,3 @@
-from Engine import *
-from Settings import *
-from Dialogs import *
-
 import gobject
 import gtk
 import hildondesktop
@@ -14,6 +10,13 @@ import osso
 import cPickle
 import string
 import pango
+import sys
+
+sys.path.insert(0, "/opt/touchsearch/lib/")
+
+from Engine import *
+from Settings import *
+from Dialogs import *
 
 HOME = os.getenv('HOME')
 
@@ -115,7 +118,11 @@ class TouchSearch(hildondesktop.HomePluginItem):
       cr_e.paint()
       
       cr_e.set_operator(cairo.OPERATOR_OVER)
-      image = cairo.ImageSurface.create_from_png("/opt/touchsearch/icons/select_search_engine.png")
+      if TouchSearch.settings.get_icon_style() == "Ghosted":
+         path = "/opt/touchsearch/icons/select_search_engine_ghosted.png"
+      else:
+         path = "/opt/touchsearch/icons/select_search_engine_color.png"
+      image = cairo.ImageSurface.create_from_png(path)
       cr_e.set_source_surface(image, 0, 7)
       cr_e.paint()
       
@@ -125,8 +132,10 @@ class TouchSearch(hildondesktop.HomePluginItem):
       cr_s.set_operator(cairo.OPERATOR_SOURCE)
       cr_s.paint()
       
-      print TouchSearch.engine.get_icon()
-      image = cairo.ImageSurface.create_from_png(TouchSearch.engine.get_icon())
+      if TouchSearch.settings.get_icon_style() == "Ghosted":
+         image = cairo.ImageSurface.create_from_png(TouchSearch.engine.get_ghosted_icon())
+      else:
+         image = cairo.ImageSurface.create_from_png(TouchSearch.engine.get_color_icon())
       
       cr_s.set_operator(cairo.OPERATOR_OVER)
       cr_s.set_source_surface(image, 10, 9)
@@ -158,7 +167,10 @@ class TouchSearch(hildondesktop.HomePluginItem):
             print corefour
             displayed_engines = []
             
-            icon = TouchSearch.engine.get_icon()
+            if TouchSearch.settings.get_icon_style() == "Ghosted":
+               icon = TouchSearch.engine.get_ghosted_icon()
+            else:
+               icon = TouchSearch.engine.get_color_icon()
             icon = gtk.gdk.pixbuf_new_from_file_at_size(icon, 122, 40)
             image = gtk.Image()
             image.set_from_pixbuf(icon)
@@ -168,7 +180,10 @@ class TouchSearch(hildondesktop.HomePluginItem):
                if not engine_name == TouchSearch.engine.get_name():
                   displayed_engines.append(engine_name)
                   engine = Engine(engine_name)
-                  icon = engine.get_icon()
+                  if TouchSearch.settings.get_icon_style() == "Ghosted":
+                     icon = engine.get_ghosted_icon()
+                  else:
+                     icon = engine.get_color_icon()
                   icon = gtk.gdk.pixbuf_new_from_file_at_size(icon, 122, 40)
                   image = gtk.Image()
                   image.set_from_pixbuf(icon)
@@ -183,7 +198,10 @@ class TouchSearch(hildondesktop.HomePluginItem):
             
          else:
             engine = TouchSearch.engine
-            icon = engine.get_icon()
+            if TouchSearch.settings.get_icon_style() == "Ghosted":
+               icon = engine.get_ghosted_icon()
+            else:
+               icon = engine.get_color_icon()
             icon = gtk.gdk.pixbuf_new_from_file_at_size(icon, 122, 40)
             image = gtk.Image()
             image.set_from_pixbuf(icon)
